@@ -35,13 +35,22 @@ def get_mnemonic(direction, prefix, p, i, f):
         length = len(params)
 
     if length > 0:
-        key = '%s CSI %s%s;*%s%s' % (direction, prefix, params[0], i, f)
+        key = '%s CSI %s;[*]%s%s' % (direction, params[0], i, f)
         if key in _DB:
             return _DB[key] 
 
     key = '%s CSI %s[%d]%s%s' % (direction, prefix, length, i, f)
     if key in _DB:
-        return _DB[key] 
+        if length > 0:
+            return _DB[key] % tuple(params)
+        else:
+            return _DB[key]
+
+    if length > 1:
+        for x in xrange(0, length):
+            key = '%s CSI %s;[%d]%s%s' % (direction, ";".join(params[:x]), length - x, i, f)
+            if key in _DB:
+                return _DB[key] % tuple(params[x:]) 
 
     key = '%s CSI %s%s%s' % (direction, prefix, i, f)
     if key in _DB:
